==> haskell-aeson-warning-parser-0.1.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-warning-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-warning-parser
version:              0.1.1
visibility:           public
id:                   aeson-warning-parser-0.1.1-Kl3UAQ4QSkJ3xPwRXWEB3E
key:                  aeson-warning-parser-0.1.1-Kl3UAQ4QSkJ3xPwRXWEB3E
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           Mike Pilgrem <public@pilgrem.com>
author:               Michael Snoyman
homepage:
    https://github.com/commercialhaskell/aeson-warning-parser#readme

synopsis:
    Library providing JSON parser that warns about unexpected fields in objects.

description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/aeson-warning-parser#readme>

category:             JSON
abi:                  bee9ed1f6c35f7ab5640ee0b93e4570c
exposed:              True
exposed-modules:      Data.Aeson.WarningParser
hidden-modules:       Paths_aeson_warning_parser
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-warning-parser-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-warning-parser-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-warning-parser-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-warning-parser
hs-libraries:         HSaeson-warning-parser-0.1.1-Kl3UAQ4QSkJ3xPwRXWEB3E
depends:
    aeson-2.1.2.1-1sit77W6SL3BciMFQH0A5E base-4.17.2.1 containers-0.6.7
    generic-deriving-1.14.6-6TxClzYqYqz2ecAJf3FfXg
    rio-0.1.22.0-JHwFk3gKw8773YeMEPamNE
    rio-prettyprint-0.1.7.0-G7Qrt66lSycFkuLKcAdtbi text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-1q9sqpstxGlGEsMEnuqYMK

haddock-interfaces:
    /usr/share/doc/haskell-aeson-warning-parser/html/aeson-warning-parser.haddock

haddock-html:         /usr/share/doc/haskell-aeson-warning-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-warning-parser-0.1.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-warning-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-warning-parser
version:              0.1.1
visibility:           public
id:                   aeson-warning-parser-0.1.1-Fvq05aE4gXp7wLDSJWNmui
key:                  aeson-warning-parser-0.1.1-Fvq05aE4gXp7wLDSJWNmui
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           Mike Pilgrem <public@pilgrem.com>
author:               Michael Snoyman
homepage:
    https://github.com/commercialhaskell/aeson-warning-parser#readme

synopsis:
    Library providing JSON parser that warns about unexpected fields in objects.

description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/aeson-warning-parser#readme>

category:             JSON
abi:                  482b5a5d5bfe6ee004b7bdae989efc53
exposed:              True
exposed-modules:      Data.Aeson.WarningParser
hidden-modules:       Paths_aeson_warning_parser
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-warning-parser-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-warning-parser-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-warning-parser-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-warning-parser
hs-libraries:         HSaeson-warning-parser-0.1.1-Fvq05aE4gXp7wLDSJWNmui
depends:
    aeson-2.1.2.1-BB6MQBhtmtsAO1zPoxRUji base-4.17.2.1 containers-0.6.7
    generic-deriving-1.14.6-6TxClzYqYqz2ecAJf3FfXg
    rio-0.1.22.0-JHwFk3gKw8773YeMEPamNE
    rio-prettyprint-0.1.7.0-ABCNatsNHM23YrX1Mioy0e text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-1q9sqpstxGlGEsMEnuqYMK

haddock-interfaces:
    /usr/share/doc/haskell-aeson-warning-parser/html/aeson-warning-parser.haddock

haddock-html:         /usr/share/doc/haskell-aeson-warning-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
